.. GPflow documentation master file, created by
   sphinx-quickstart on Mon Jul 25 12:37:37 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

GPflow Documentation
==================================

.. toctree::
   :maxdepth: 2
   :caption: Intro:

   intro
   notebooks/intro
   notebooks/intro_to_gpflow2
   notebooks/gpflow2_upgrade_guide

.. toctree::
   :maxdepth: 1
   :caption: Examples:
   :glob:

   notebooks_file
   derivations

.. toctree::
   :maxdepth: 3
   :glob:
   :caption: API:

   gpflow/index
